@@ -2,7 +2,7 @@
 automatic width mix-in classes for kivy widgets
 ===============================================
 
-This ae portion is providing classes to mix them into any kivy widget with a `texture` property (like e.g.
+this ae portion is providing classes to mix them into any kivy widget with a `texture` property (like e.g.
 :class:`~kivy.uix.label.Label` or :class:`~kivy.uix.button.Button`), to automatically size and resize widgets and/or to
 display a long text as scrolling ticker within a tall widget.
 
@@ -10,32 +10,32 @@ display a long text as scrolling ticker within a tall widget.
 automatic font size iteration with animation
 --------------------------------------------
 
-Mix-in the :class:`AutoFontSizeBehavior` into any kivy widget with a `texture` property, to automatically grow or shrink
+mix-in the :class:`AutoFontSizeBehavior` into any kivy widget with a `texture` property, to automatically grow or shrink
 the font size to fully fill the width/height of the widget with the size of their texture.
 
-More details see in the documentation of the :class:`AutoFontSizeBehavior` class.
+more details see in the documentation of the :class:`AutoFontSizeBehavior` class.
 
 
 automatic container width with opening animation
 ------------------------------------------------
 
-The class :class:`ContainerChildrenAutoWidthBehavior` determines the optimal width of a container widget, so that the
+the class :class:`ContainerChildrenAutoWidthBehavior` determines the optimal width of a container widget, so that the
 text of any its children widgets is fully visible/displayed.
 
-The optimal container width is determined by increasing width of the container in iterations, which are implemented
-through a kivy :class:`~kivy.animation.Animation`. As soon as the texts of all children are fully displayed (or the
+the optimal container width is determined by increasing width of the container in iterations, which are implemented
+through a kivy :class:`~kivy.animation.Animation`. as soon as the texts of all children are fully displayed (or the
 maximum width is reached) the animation stops.
 
-More details see in the documentation of the :class:`ContainerChildrenAutoWidthBehavior` class.
+more details see in the documentation of the :class:`ContainerChildrenAutoWidthBehavior` class.
 
 
 automatic ticker animation
 --------------------------
 
-Mix-in the :class:`SimpleAutoTickerBehavior` class to automatic slide the texture of a widget if it is too big to be
+mix-in the :class:`SimpleAutoTickerBehavior` class to automatic slide the texture of a widget if it is too big to be
 completely/fully displayed, like in a news-ping-pong-ticker.
 
-For more details check the documentation of the :class:`SimpleAutoTickerBehavior` class.
+for more details check the documentation of the :class:`SimpleAutoTickerBehavior` class.
 """
 from typing import Callable, Dict, Optional
 
@@ -56,19 +56,19 @@ except ImportError:
     MAX_FONT_SIZE = 99
 
 
-__version__ = '0.1.16'
+__version__ = '0.3.18'
 
 
 class AutoFontSizeBehavior:
     """ mix-in to interpolate the optimal font size so that the texture is filling the full width of the widget.
 
-    The desired spacing (left plus right) between the texture border and the widget borders can be set via the
-    :attr:`auto_font_text_spacing` property. Additional padding can be added via the `padding_x` property of the
+    the desired spacing (left plus right) between the texture border and the widget borders can be set via the
+    :attr:`auto_font_text_spacing` property. additional padding can be added via the `padding_x` property of the
     mixing-in widget.
 
-    To disable the animation set the length of the :data:`auto_font_anim_duration` to zero or very short value.
+    to disable the animation set the length of the :data:`auto_font_anim_duration` to zero or very short value.
 
-    The minimum and maximum of the texture font size can be restricted by setting the attributes
+    the minimum and maximum of the texture font size can be restricted by setting the attributes
     :attr:`auto_font_min_size` and :attr:`auto_font_max_size`.
     """
     # abstracts
@@ -175,15 +175,15 @@ Factory.register('AutoFontSizeBehavior', cls=AutoFontSizeBehavior)
 class ContainerChildrenAutoWidthBehavior:
     """ detect minimum width for the complete display of the textures of all children at opening with animation.
 
-    This mix-in class can be added to any type of container or layout widget to provide a consistent API with
+    this mix-in class can be added to any type of container or layout widget to provide a consistent API with
     :meth:`.open` and :meth:`.close` methods, a :meth:`.on_complete_opened` event and a :attr:`.container` attribute.
 
-    .. note:: A `container` attribute will be automatically created for container classes without it.
+    .. note:: a `container` attribute will be automatically created for container classes without it.
 
-    The animation starts when the :meth:`~ContainerChildrenAutoWidthBehavior.open` method get called. This call will be
+    the animation starts when the :meth:`~ContainerChildrenAutoWidthBehavior.open` method get called. this call will be
     forwarded via `super()` to the container if it has an `open` method.
 
-    At animation start the width of this container will be set to value of the :attr:`auto_width_start` attribute. Then
+    at animation start the width of this container will be set to value of the :attr:`auto_width_start` attribute. then
     the container width increases via the running animation until, either:
 
     * the container width is greater than the value of the :attr:`auto_width_minimum` attribute
@@ -192,11 +192,11 @@ class ContainerChildrenAutoWidthBehavior:
     * the container width reaches the app window width minus the window padding specified in the
       :attr:`auto_width_window_padding` attribute.
 
-    The window width gets bound to the container width to ensure proper displaying if the window width changes.
+    the window width gets bound to the container width to ensure proper displaying if the window width changes.
 
     :Events:
         `on_complete_opened`:
-            Fired when the container width animation is finished or stopped because all children are fully visible.
+            fired when the container width animation is finished or stopped because all children are fully visible.
 
     """
     container: Widget           #: widget to add the dynamic children to (provided by the widget to be mixed into)
@@ -301,10 +301,9 @@ class ContainerChildrenAutoWidthBehavior:
 
         :return:                0.0 until complete width got detected, then the last detected minimum container width.
         """
-        if not self._complete_width:
-            if all(chi.texture_size[0] + self.auto_width_child_padding < self.width
-                   for chi in self.container.children if isinstance(chi, Label)):
-                self._complete_width = self.width
+        if not self._complete_width and all(chi.texture_size[0] + self.auto_width_child_padding < self.width
+                                            for chi in self.container.children if isinstance(chi, Label)):
+            self._complete_width = self.width
         return self._complete_width
 
     def _on_complete_opened(self, *_args):
@@ -320,9 +319,8 @@ class ContainerChildrenAutoWidthBehavior:
 
     def _open_width_progress(self, _anim: Animation, _self: Widget, _progress: float):
         """ animation on_progress event handler. """
-        if self.width > self.auto_width_minimum:
-            if self._detect_complete_width():
-                self._width_anim.stop(self)
+        if self.width > self.auto_width_minimum and self._detect_complete_width():
+            self._width_anim.stop(self)
 
     def _win_width_bind(self):
         """ bind :class:`~kivy.core.window.Window` width property to container width. """
@@ -335,21 +333,20 @@ Factory.register('ContainerChildrenAutoWidthBehavior', cls=ContainerChildrenAuto
 class SimpleAutoTickerBehavior:
     """ mix-in class to slide texture in a ping-pong-like-ticker animation, if too long to be displayed completely.
 
-    If the `text` or `size` of the widget where this class get mixed in changes then this instance is first determining
-    the number of characters that can be displayed completely in this widget. This is done with an kivy animation. The
+    if the `text` or `size` of the widget where this class get mixed in changes then this instance is first determining
+    the number of characters that can be displayed completely in this widget. this is done with an kivy animation. the
     duration of this animation can be set via the property :attr:`auto_ticker_length_anim_duration`.
 
-    To adjust the padding space between the widget border and their texture width, the property
+    to adjust the padding space between the widget border and their texture width, the property
     :attr:`auto_ticker_text_spacing` can be set accordingly.
 
-    After determining the maximum number of characters that can be displayed and storing this value into the private
+    after determining the maximum number of characters that can be displayed and storing this value into the private
     attribute :attr:`_ticker_text_length` a second animation - the offset animation - gets started to slide/scroll the
-    text. The speed of the offset animation can be set via the property :attr:`auto_ticker_offset_anim_speed`.
+    text. the speed of the offset animation can be set via the property :attr:`auto_ticker_offset_anim_speed`.
 
     .. note::
-        While the ticker animations are running the `text` property of the widget is only containing the
-        visible part of the full initial text string. Use the private attribute :attr:`_ori_text` for
-        to determine the full text string.
+        while the ticker animations are running the `text` property of the widget is only containing the visible part of
+        the full initial text string. use the private attribute :attr:`_ori_text` to determine the full text string.
 
     """
     # abstracts
